

library(tidyverse)
library(dplyr)

input_path <- "/esarchive/scratch/ccarnere/AQS_database/postprocessed/regional/statistics/"
output_path <- input_path
setwd(input_path)

# merge all files in a same directory containing a string
merge_stats <- function(input_path, pol){
  df <- list.files(path = input_path,
                 pattern = paste0("Stats_",pol), 
                 recursive=TRUE) %>%
    map_dfr(readRDS)
  
  return(df)
}


df_no2 <- merge_stats(input_path, "no2")
df_o3 <- merge_stats(input_path, "o3")
df_pm10 <- merge_stats(input_path, "pm10")
df_pm2p5 <- merge_stats(input_path, "pm2p5")
df_pm2p5_gbm <- merge_stats(input_path, "pm2p5_gbm")
df_so2 <- merge_stats(input_path, "so2")
df_co <- merge_stats(input_path, "co")

df <- bind_rows(df_no2,df_o3,df_pm10,df_pm2p5,df_pm2p5_gbm,df_so2) %>%
  dplyr::select(-FAC2,-MGE,-NMB,-NMGE,-IOA)


#TODO plot timeseries of R, MB, RMSE, COE for each pollutant
#TODO plot_model_vs_obs.R


text_size=15
statistic.list <- c("RMSE","r","MB","COE")


df2 <- df %>% 
  dplyr::filter(aggreg=="hourly") %>%
  dplyr::mutate(r2 = r^2) %>%
  dplyr::select(-n, -aggreg) %>%
  pivot_wider(names_from = "model",values_from = c("RMSE","r","r2","MB","COE"))


for(statistic in statistic.list){
  
  p <- df2 %>%
    dplyr::mutate(year=as.factor(year)) %>%
    ggplot(aes(x=year, ymin = !!sym(paste0(statistic,"_raw_model")), ymax = !!sym(paste0(statistic,"_UK_model")), color = pol, group=pol)) +
    geom_linerange(position = position_dodge(width = 0.5), size = 5)+
    geom_point(aes(y=!!sym(paste0(statistic,"_raw_model"))),shape=21,color="black",position = position_dodge(width = 0.5))+
    geom_point(aes(y=!!sym(paste0(statistic,"_UK_model"))),shape=20,size=4,color="black",position = position_dodge(width = 0.5))+
    # geom_segment(aes(x=year,xend=year,y=RMSE_raw_model,yend=RMSE_UK_model,col=pol),
    #              arrow = arrow(,length = unit(4, "mm")),
    #              color="black", position = position_dodge(width = 0.5))+
    geom_linerange(aes(x=year,y=!!sym(paste0(statistic,"_raw_model"))),
                   color="black", position = position_dodge(width = 0.5))+
    labs(y=statistic,
         x="",
         color="Pollutant") +
    scale_color_viridis_d(alpha=0.7)+
    theme_classic()+
    theme(text = element_text(size=text_size),
          panel.grid.major = element_blank(), 
          panel.background = element_rect(colour = "black", size=0.5),
          axis.text.x = element_text(angle = 45, hjust = 1))
  
  ggsave(paste0(output_path,statistic,".png"),
         width=8,
         height=6,
         units="in",
         dpi = 1200)

}